package com.prisma.api.mutations

import com.prisma.api.ApiSpecBase
import com.prisma.shared.schema_dsl.SchemaDsl
import org.scalatest.{FlatSpec, Matchers}

class SettingNodeSelectorToNullSpec extends FlatSpec with Matchers with ApiSpecBase {

  "Setting a where value to null " should " work when there is no further nesting " in {
    val project = SchemaDsl.fromStringV11() {
      """
        |type A {
        |  id: ID! @id
        |  b: String @unique
        |  key: String! @unique
        |}
      """
    }
    database.setup(project)

    server.query(
      """mutation a {
        |  createA(data: {
        |    b: "abc"
        |    key: "abc"
        |  }) {
        |    id
        |  }
        |}""",
      project
    )

    val res = server.query(
      """mutation b {
        |  updateA(
        |    where: { b: "abc" }
        |    data: {
        |      b: null
        |    }) {
        |    b
        |  }
        |}""",
      project
    )

    res.toString() should be("""{"data":{"updateA":{"b":null}}}""")
  }
}
